@@ -100,17 +100,61 @@ public interface IDocumentConverterInformationMBean {
 
     // -------------------------------------------------------------------------
 
+    /**
+     * @return The peak total number of Jobs in queue for from the beginning of the last reset/initialization on
+     */
+    int getPeakJobCountInAsyncQueue_Total();
+
+    // -------------------------------------------------------------------------
+
     /**
      * @return The toal number of jobs that returned with a timeout error
      */
     long getJobErrorsTimeout();
 
     /**
-     * @return The toal number of jobs that returned with an error in general
+     * @return The total number of jobs that returned with an error in general
      */
     long getJobErrorsTotal();
 
 
+    // -------------------------------------------------------------------------
+
+    /**
+     * @return The total number of physical conversions
+     */
+    long getConversionCount();
+
+    /**
+     * @return The total number of conversions that used more than one run to perform a conversion
+     */
+    long getConversionCountWithMultipleRuns();
+
+    /**
+     * @return The total number of conversions that returned with a {@link JobError.GENERAL}
+     */
+    long getConversionErrorsGeneral();
+
+    /**
+     * @return The total number of conversions that returned with a {@link JobError.TIMEOUT}
+     */
+    long getConversionErrorsTimeout();
+
+    /**
+     * @return The total number of conversions that returned with a {@link JobError.DISPOSED}
+     */
+    long getConversionErrorsDisposed();
+
+    /**
+     * @return The total number of conversions that returned with a {@link JobError.PASSWORD}
+     */
+    long getConversionErrorsPassword();
+
+    /**
+     * @return The total number of conversions that returned with a {@link JobError.NO_CONTENT}
+     */
+    long getConversionErrorsNoContent();
+
     // -------------------------------------------------------------------------
 
     /**
