@@ -103,9 +103,18 @@ public interface IJobProcessor {
      * Returns the current status of the Job with the given id
      *
      * @param jobIdStr
-     * @return the current status of the Job
+     * @return
      */
-    JobStatus getJobStatus(String jobIdStr);
+    /**
+     * @param jobIdStr
+     * @param jobError [out]
+     * @return The current status of the {@link IJob}.</br></br>
+     *  If the {@link JobError} array parameter
+     *  is not null and not empty, the first element
+     *  of this array will contain the specific {@link JobError},
+     *  according to the returned {@link JobStatus}
+     */
+    JobStatus getJobStatus(String jobIdStr, JobError[] jobError);
 
     /**
      * terminates the JobProcessor
