@@ -50,6 +50,7 @@
 
 package com.openexchange.documentconverter;
 
+import java.io.EOFException;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
@@ -60,6 +61,7 @@ import java.net.URL;
 import java.net.URLConnection;
 import java.net.URLDecoder;
 import java.util.HashMap;
+import java.util.UUID;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
@@ -130,9 +132,9 @@ public abstract class ManagerBasics implements ILogProvider {
             hashBuilder = new StringBuilder();
 
             try {
-                hashBuilder.append(Long.toString(file.length())).append('_').append(
-                    Long.toString(FileUtils.checksumCRC32(file)));
-            } catch (Exception e) {
+                hashBuilder.append(Long.toString(file.length())).append('_').
+                    append(Long.toString(FileUtils.checksumCRC32(file))).append('-');
+            } catch (final Exception e) {
                 logExcpImpl(m_basicLogProvider, e);
             }
 
@@ -141,7 +143,7 @@ public abstract class ManagerBasics implements ILogProvider {
             // input file hash in order to be able to perform locale based
             // conversions
             if (!StringUtils.isEmpty(locale)) {
-                hashBuilder.append('-').append(locale).append('-');
+                hashBuilder.append(locale).append('-');
             }
         }
 
@@ -202,13 +204,40 @@ public abstract class ManagerBasics implements ILogProvider {
                     tmpFile = File.createTempFile(prefix, ".tmp", scratchDir);
                 }
             }
-        } catch (IOException e) {
+        } catch (final IOException e) {
             logExcpImpl(m_basicLogProvider, e);
         }
 
         return tmpFile;
     }
 
+    /**
+     * @param tmpRoot
+     * @return
+     */
+    public static File createTempDir(@NonNull String tmpRoot) {
+        final File root = new File(tmpRoot);
+        File tempDirFile = null;
+
+        if (root.canWrite()) {
+            while (null == tempDirFile) {
+                tempDirFile = new File(tmpRoot, UUID.randomUUID().toString());
+
+                try {
+                    FileUtils.forceMkdir(tempDirFile);
+                } catch (IOException e) {
+                    ManagerBasics.logExcpImpl(m_basicLogProvider, e);
+                }
+
+                if (!tempDirFile.exists()) {
+                    tempDirFile = null;
+                }
+            }
+        }
+
+        return tempDirFile;
+    }
+
     /**
      * @param dirFile
      * @return
@@ -220,7 +249,7 @@ public abstract class ManagerBasics implements ILogProvider {
             if (!directory.exists()) {
                 try {
                     FileUtils.forceMkdir(directory);
-                } catch (IOException e) {
+                } catch (final IOException e) {
                     logExcpImpl(m_basicLogProvider, e);
                 }
 
@@ -262,7 +291,7 @@ public abstract class ManagerBasics implements ILogProvider {
                         }
                     }
                 }
-            } catch (IOException e) {
+            } catch (final IOException e) {
                 logExcpImpl(m_basicLogProvider, e);
             }
         }
@@ -288,11 +317,8 @@ public abstract class ManagerBasics implements ILogProvider {
             try (final InputStream inputStm = (InputStream) jobProperties.get(Properties.PROP_INPUT_STREAM)) {
                 if (null != inputStm) {
                     if (null != (inputFile = ManagerBasics.createTempFile(FileUtils.getTempDirectoryPath(), "oxcs", null))) {
-                        inputFile.deleteOnExit();
-
                         try {
                             FileUtils.copyInputStreamToFile(inputStm, inputFile);
-                            IOUtils.closeQuietly(inputStm);
 
                             // set the just filled inputFile as new source at our
                             // job
@@ -303,7 +329,7 @@ public abstract class ManagerBasics implements ILogProvider {
                             // the temporarily created file needs to be deleted by
                             // the caller of this method later in time
                             deleteInputFile[0] = true;
-                        } catch (IOException e) {
+                        } catch (final IOException e) {
                             logExcpImpl(m_basicLogProvider, e);
 
                             FileUtils.deleteQuietly(inputFile);
@@ -311,7 +337,7 @@ public abstract class ManagerBasics implements ILogProvider {
                         }
                     }
                 }
-            } catch (IOException e) {
+            } catch (final IOException e) {
                 logExcpImpl(m_basicLogProvider, e);
             }
         }
@@ -325,7 +351,7 @@ public abstract class ManagerBasics implements ILogProvider {
                 if ((inputStm.read(buffer) > 0) && new String(buffer, "UTF-8").trim().toLowerCase().startsWith("%pdf-")) {
                     jobProperties.put(Properties.PROP_INPUT_TYPE, "pdf");
                 }
-            } catch (IOException e) {
+            } catch (final IOException e) {
                 logExcpImpl(m_basicLogProvider, e);
             }
         }
@@ -459,7 +485,10 @@ public abstract class ManagerBasics implements ILogProvider {
             String message = (null != e) ? e.getMessage() : null;
             final String lowerMessage = (null != message) ? message.toLowerCase() : null;
 
-            if ((e instanceof SocketException) || (e instanceof SocketTimeoutException) || ((e instanceof IOException) && (null != lowerMessage) && ((lowerMessage.contains("broken pipe") || lowerMessage.contains(("connection reset")) || lowerMessage.contains(("invalid stream")))))) {
+            if ((e instanceof SocketException) ||
+                (e instanceof SocketTimeoutException) ||
+                (e instanceof EOFException) ||
+                ((e instanceof IOException) && (null != lowerMessage) && ((lowerMessage.contains("broken pipe") || lowerMessage.contains(("connection reset")) || lowerMessage.contains(("invalid stream")))))) {
                 // ignore socket exceptions; these may occur, when a connection timeout has happened
             } else {
                 if (null != message) {
@@ -469,8 +498,8 @@ public abstract class ManagerBasics implements ILogProvider {
                         final int endLength = Math.min(message.length() - beginLength, Properties.MAX_ERROR_MESSAGE_END_LENGTH);
                         message = message.substring(0, beginLength) + ((endLength > 0) ? ("..." + message.substring(message.length() - endLength)) : "");
                     }
-                } else {
-                    message = "unknown";
+                } else if (null != e){
+                    message = e.getClass().getName();
                 }
 
                 logImpl(logProvider, LogType.LOGTYPE_ERROR, "Documentconverter caught an exception: \n" + message, null);
@@ -518,7 +547,7 @@ public abstract class ManagerBasics implements ILogProvider {
         if (null != fileName) {
             try {
                 fileName = URLDecoder.decode(fileName, "UTF-8");
-            } catch (UnsupportedEncodingException e) {
+            } catch (final UnsupportedEncodingException e) {
                 logExcpImpl(logProvider, e);
             }
 
@@ -535,7 +564,7 @@ public abstract class ManagerBasics implements ILogProvider {
         }
 
         if ((null != jobProperties) && !jobProperties.isEmpty()) {
-            for (String key : jobProperties.keySet()) {
+            for (final String key : jobProperties.keySet()) {
                 // log all info_ properties but info_Filename only in case of an error
                 if (key.startsWith(Properties.INFO_PREFIX) && !key.equals(Properties.PROP_INFO_FILENAME)) {
                     final Object obj = jobProperties.get(key);
@@ -547,7 +576,7 @@ public abstract class ManagerBasics implements ILogProvider {
                     }
 
                     infoStrBuilder.append(key.substring(Properties.INFO_PREFIX.length())).append('=').append(
-                            (null != obj) ? obj.toString() : "null");
+                        (null != obj) ? obj.toString() : "null");
                 }
             }
 
